Bugzilla, Git and Github
========================

A love story with Bugzilla, git and Github.

This script encapsulates as much automation as possible when working
with Git and especially with Bugzilla and Github.

The idea is that you can recognize certain patterns in your day-to-day
work with these tools and wrapping that up in one script.

Basically, anything you do with git where you find yourself repeating
yourself more than once can be automated in some smart way.
